Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(188)

Unified Diff: content/browser/renderer_host/render_widget_host_view_aura.cc

Issue 2040333002: Merge to M52: Fix a bug with the Chrome legacy window at times becoming a top level window with a n… (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2743
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/legacy_render_widget_host_win.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/renderer_host/render_widget_host_view_aura.cc
diff --git a/content/browser/renderer_host/render_widget_host_view_aura.cc b/content/browser/renderer_host/render_widget_host_view_aura.cc
index 9d63bbdd10810dde510a608cf40df12e374be4c6..f887e756572bd84ea8b95cc7a3c35572587125e6 100644
--- a/content/browser/renderer_host/render_widget_host_view_aura.cc
+++ b/content/browser/renderer_host/render_widget_host_view_aura.cc
@@ -2579,10 +2579,10 @@ void RenderWidgetHostViewAura::RemovingFromRootWindow() {
delegated_frame_host_->ResetCompositor();
#if defined(OS_WIN)
// Update the legacy window's parent temporarily to the desktop window. It
// will eventually get reparented to the right root.
if (legacy_render_widget_host_HWND_)
- legacy_render_widget_host_HWND_->UpdateParent(::GetDesktopWindow());
+ legacy_render_widget_host_HWND_->UpdateParent(ui::GetHiddenWindow());
#endif
}
« no previous file with comments | « content/browser/renderer_host/legacy_render_widget_host_win.cc ('k') | no next file » | no next file with comments »
@@ -2579,10 +2579,10 @@ void RenderWidgetHostViewAura::RemovingFromRootWindow() {
delegated_frame_host_->ResetCompositor();
#if defined(OS_WIN)
- // Update the legacy window's parent temporarily to the desktop window. It
+ // Update the legacy window's parent temporarily to the hidden window. It
// will eventually get reparented to the right root.
if (legacy_render_widget_host_HWND_)

Powered by Google App Engine
This is Rietveld 408576698